#
# spec file for package libsvm
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Summary:        A Library for Support Vector Machines
License:        BSD-3-Clause
Group:          Development/Languages/C and C++
Name:           libsvm
Version:        3.21
Release:        4.2
Url:            http://www.csie.ntu.edu.tw/~cjlin/libsvm/
Source0:        %{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  ncurses-devel
BuildRequires:  javapackages-tools
BuildRequires:  java-devel
BuildRequires:  python-devel
%if 0%{?suse_version} <= 1110
%{!?python_sitelib:  %global python_sitelib  %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%endif

%description
LIBSVM is an integrated software for support vector classification,
(C-SVC, nu-SVC), regression (epsilon-SVR, nu-SVR) and distribution 
estimation (one-class SVM). It supports multi-class classification.

%package -n svm-tools
Summary:        A set of tools to use with libsvm
Group:          Development/Languages/C and C++

%description -n svm-tools
LIBSVM is an integrated software for support vector classification,
(C-SVC, nu-SVC), regression (epsilon-SVR, nu-SVR) and distribution 
estimation (one-class SVM). It supports multi-class classification.

%package -n libsvm2
Summary:        A Library for Support Vector Machines
Group:          System/Libraries

%description -n libsvm2
LIBSVM is an integrated software for support vector classification,
(C-SVC, nu-SVC), regression (epsilon-SVR, nu-SVR) and distribution 
estimation (one-class SVM). It supports multi-class classification.


%package	devel
Summary:        C headers for developing programs with libsvm
Group:          Development/Libraries/C and C++
Requires:       libsvm2 = %{version}
Requires:       ncurses-devel

%description	devel
This package contains the libraries and header files needed for
developing applications with libsvm.

%package -n python-svm
Summary:        Python bindings libsvm
Group:          Development/Languages/Python
Requires:       gnuplot
Requires:       svm-tools = %{version}
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description -n python-svm
This package contains the python bindings libsvm.

%package java
Summary:        Python bindings libsvm
Group:          Development/Libraries/Java
Requires:       libsvm2 = %{version}
Requires:       java >= 1.6.0
Requires:       javapackages-tools
Requires(post):   javapackages-tools
Requires(postun): javapackages-tools
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description java
This package contains the java bindings libsvm.

%prep
%setup -q

%build
export CFLAGS="%{optflags} -Wconversion -fPIC"
make
make all
make lib
rm -f java/libsvm.jar
make -C java

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_javadir}
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_includedir}/libsvm
mkdir -p %{buildroot}%{python_sitelib}/svm

install -m 755 svm-train %{buildroot}%{_bindir}
install -m 755 svm-scale %{buildroot}%{_bindir}
install -m 755 svm-predict %{buildroot}%{_bindir}
install -m 755 ./tools/checkdata.py %{buildroot}%{_bindir}/svm-checkdata
install -m 755 ./tools/grid.py %{buildroot}%{_bindir}/svm-grid
install -m 755 ./tools/subset.py %{buildroot}%{_bindir}/svm-subset
install -m 755 ./tools/easy.py %{buildroot}%{_bindir}/svm-easy
install -m 644 svm.h %{buildroot}%{_includedir}/libsvm/
install -m 755 libsvm.so.2 %{buildroot}%{_libdir}
ln -s %{_libdir}/libsvm.so.2 %{buildroot}%{_libdir}/libsvm.so
mv ./python/README README-python
mv ./tools/README README-python-tools

install -m 755 ./python/svm.py %{buildroot}%{python_sitelib}/svm
install -m 755 ./python/svmutil.py %{buildroot}%{python_sitelib}/svm
touch %{buildroot}%{python_sitelib}/svm/__init__.py

install -m 755 ./java/%{name}.jar %{buildroot}%{_javadir}/%{name}.jar

%fdupes -s %{buildroot}

%post -n libsvm2 -p /sbin/ldconfig

%postun -n libsvm2 -p /sbin/ldconfig

%files -n svm-tools
%defattr(-,root,root,-)
%doc FAQ.html README
%{_bindir}/svm-train
%{_bindir}/svm-scale
%{_bindir}/svm-predict

%files -n libsvm2
%defattr(-,root,root,-)
%doc COPYRIGHT
%{_libdir}/libsvm.so.2

%files devel
%defattr(-,root,root,-)
%{_includedir}/libsvm
%{_libdir}/libsvm.so

%files -n python-svm
%defattr(-,root,root,-)
%doc README-python README-python-tools
%{_bindir}/svm-checkdata
%{_bindir}/svm-grid
%{_bindir}/svm-subset
%{_bindir}/svm-easy
%{python_sitelib}/svm

%files java
%defattr(-,root,root,-)
%{_javadir}/%{name}.jar

%changelog
* Thu Dec 31 2015 p.drouand@gmail.com
- Update to version 3.21
  * No changelog available
* Mon Oct 26 2015 p.drouand@gmail.com
- Update to version 3.20
  * No Changelog available
- Fix Groups
- Split out the tools in a tools subpackage
- Package java tools into their own package
- Add build dependencies for java
  * javapackages-tools
  * java-devel
- Depend on java-devel instead of jave
- Remove depreciated %%py_requires and %%clean section
- Remove dependency on pkgconfig; the devel package doesn't contain
  any pkgconfig file
* Sat Apr  5 2014 scorot@free.fr
- fix permissions of %%%%doc in libsvm2 package
* Thu Mar 13 2014 toddrme2178@gmail.com
- Update to 3.17
  * no upstream changelog
* Fri Sep  7 2012 scorot@free.fr
- add python in build requirements
* Fri Sep  7 2012 scorot@free.fr
- repackgage python file into a python module package
- put liibrary into a separate package
- spec file reformating
- build with optflags
- fix license
- remove unneeded libtool from build requirements
